# `testpypiEG` - My Simple Project

* Opt1
* Opt2
* Opt3

## Install

```python
pip install testpypiEG
```

### Usage

```python
from testpypiEG.m_mod_EG import name as n
from testpypiEG.m_mod_EG import  get_numpy_arr
>>> n("Name", "Surname")
Name_Surname
>>> get_numpy_arr([1,2,3,4,5])
[1 2 3 4 5]
```